# © Copyright 2025-2026, Query.Farm LLC - https://query.farm
# SPDX-License-Identifier: Apache-2.0

"""Conformance test suite — re-exported from vgi_rpc.conformance._pytest_suite.

The canonical test classes live in the package so other language implementations
can import and run them without cloning the repository.
"""

from vgi_rpc.conformance._pytest_suite import *  # noqa: F403
